@@ -15,5 +15,5 @@ def check_limit():
 
 
 if "api.materialsproject" in DEFAULT_ENDPOINT:
-    check_limit = limits(calls=MAPISettings().requests_per_min, period=60)(check_limit)
+    check_limit = limits(calls=MAPISettings().REQUESTS_PER_MIN, period=60)(check_limit)
     check_limit = sleep_and_retry(check_limit)
