@@ -3,7 +3,7 @@ from mp_api.routes.elasticity.models import ElasticityDoc
 
 from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
 from mp_api.routes.elasticity.query_operators import (
-    ChemsysQuery,
+    ElasticityChemsysQuery,
     BulkModulusQuery,
     ShearModulusQuery,
     PoissonQuery,
@@ -15,7 +15,7 @@ def elasticity_resource(elasticity_store):
         elasticity_store,
         ElasticityDoc,
         query_operators=[
-            ChemsysQuery(),
+            ElasticityChemsysQuery(),
             BulkModulusQuery(),
             ShearModulusQuery(),
             PoissonQuery(),
