@@ -24,8 +24,7 @@ class GrainBoundaryRester(BaseRester[GrainBoundaryDoc]):
         type: Optional[GBTypeEnum] = None,
         chemsys: Optional[str] = None,
         pretty_formula: Optional[str] = None,
-        sort_field: Optional[str] = None,
-        ascending: Optional[bool] = None,
+        sort_fields: Optional[List[str]] = None,
         num_chunks: Optional[int] = None,
         chunk_size: int = 1000,
         all_fields: bool = True,
@@ -45,8 +44,7 @@ class GrainBoundaryRester(BaseRester[GrainBoundaryDoc]):
             type (GBTypeEnum): Grain boundary type.
             chemsys (str): Dash-delimited string of elements in the material.
             pretty_formula (str): Formula of the material.
-            sort_field (str): Field used to sort results.
-            ascending (bool): Whether sorting should be in ascending order.
+            sort_fields (List[str]): Fields used to sort results. Prefix with '-' to sort in descending order.
             num_chunks (int): Maximum number of chunks of data to yield. None will yield all possible.
             chunk_size (int): Number of data entries per chunk.
             all_fields (bool): Whether to return all fields in the document. Defaults to True.
@@ -100,11 +98,10 @@ class GrainBoundaryRester(BaseRester[GrainBoundaryDoc]):
         if pretty_formula:
             query_params.update({"pretty_formula": pretty_formula})
 
-        if sort_field:
-            query_params.update({"sort_field": sort_field})
-
-        if ascending is not None:
-            query_params.update({"ascending": ascending})
+        if sort_fields:
+            query_params.update(
+                {"sort_fields": ",".join([s.strip() for s in sort_fields])}
+            )
 
         query_params = {
             entry: query_params[entry]
