@@ -1,5 +1,5 @@
 from maggma.api.resource import ReadOnlyResource
-from mp_api.routes.piezo.models import PiezoDoc
+from emmet.core.polar import PiezoelectricDoc
 
 from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
 from mp_api.routes.piezo.query_operators import PiezoelectricQuery
@@ -8,12 +8,14 @@ from mp_api.routes.piezo.query_operators import PiezoelectricQuery
 def piezo_resource(piezo_store):
     resource = ReadOnlyResource(
         piezo_store,
-        PiezoDoc,
+        PiezoelectricDoc,
         query_operators=[
             PiezoelectricQuery(),
             SortQuery(),
             PaginationQuery(),
-            SparseFieldsQuery(PiezoDoc, default_fields=["task_id", "last_updated"]),
+            SparseFieldsQuery(
+                PiezoelectricDoc, default_fields=["material_id", "last_updated"]
+            ),
         ],
         tags=["Piezoelectric"],
         disable_validation=True,
