@@ -32,14 +32,24 @@ es_excluded_params = [
 
 sub_doc_fields = []  # type: list
 
-es_alt_name_dict = {}  # type: dict
+es_alt_name_dict = {
+    "exclude_elements": "material_id",
+    "formula": "material_id",
+}  # type: dict
 
 es_custom_field_tests = {
     "magnetic_ordering": Ordering.FM,
+    "formula": "CoO2",
+    "chemsys": "Co-O",
+    "elements": ["Co", "O"],
+    "exclude_elements": ["Co"],
 }  # type: dict
 
 
-@pytest.mark.skipif(os.environ.get("MP_API_KEY", None) is None, reason="No API key found.")
+@pytest.mark.xfail(reason="Until deployment of new API")
+@pytest.mark.skipif(
+    os.environ.get("MP_API_KEY", None) is None, reason="No API key found."
+)
 def test_es_client(es_rester):
     # Get specific search method
     search_method = None
@@ -90,7 +100,10 @@ def test_es_client(es_rester):
 
                 doc = search_method(**q)[0].dict()
 
-                assert doc[project_field if project_field is not None else param] is not None
+                assert (
+                    doc[project_field if project_field is not None else param]
+                    is not None
+                )
 
 
 bs_custom_field_tests = {
@@ -113,7 +126,9 @@ def bs_rester():
     rester.session.close()
 
 
-@pytest.mark.skipif(os.environ.get("MP_API_KEY", None) is None, reason="No API key found.")
+@pytest.mark.skipif(
+    os.environ.get("MP_API_KEY", None) is None, reason="No API key found."
+)
 def test_bs_client(bs_rester):
     # Get specific search method
     search_method = None
@@ -165,7 +180,9 @@ def dos_rester():
     rester.session.close()
 
 
-@pytest.mark.skipif(os.environ.get("MP_API_KEY", None) is None, reason="No API key found.")
+@pytest.mark.skipif(
+    os.environ.get("MP_API_KEY", None) is None, reason="No API key found."
+)
 def test_dos_client(dos_rester):
     # Get specific search method
     search_method = None
@@ -190,4 +207,7 @@ def test_dos_client(dos_rester):
             if param != "projection_type" and param != "magnetic_ordering":
                 doc = doc["total"]["1"]
 
-            assert doc[project_field if project_field is not None else param] is not None
+            assert (
+                doc[project_field if project_field is not None else param] is not None
+            )
+
